@@ -26,15 +26,15 @@
 #include <libxml/parser.h>
 
 static gboolean          imgur_upload_job          (ScreenshooterJob  *job,
-                                                    GValueArray       *param_values,
+                                                    GArray            *param_values,
                                                     GError           **error);
 
 static gboolean
-imgur_upload_job (ScreenshooterJob *job, GValueArray *param_values, GError **error)
+imgur_upload_job (ScreenshooterJob *job, GArray *param_values, GError **error)
 {
   const gchar *image_path, *title;
   gchar *online_file_name = NULL;
-  gchar* proxy_uri;
+  const gchar* proxy_uri;
   SoupURI *soup_proxy_uri;
 #if DEBUG > 0
   SoupLogger *log;
@@ -54,20 +54,19 @@ imgur_upload_job (ScreenshooterJob *job, GValueArray *param_values, GError **err
 
   g_return_val_if_fail (SCREENSHOOTER_IS_JOB (job), FALSE);
   g_return_val_if_fail (param_values != NULL, FALSE);
-  g_return_val_if_fail (param_values->n_values == 2, FALSE);
-  g_return_val_if_fail (G_VALUE_HOLDS_STRING (&param_values->values[0]), FALSE);
-  g_return_val_if_fail (G_VALUE_HOLDS_STRING (&param_values->values[1]), FALSE);
+  g_return_val_if_fail (param_values->len == 2, FALSE);
+  g_return_val_if_fail ((G_VALUE_HOLDS_STRING (g_array_index(param_values, GValue*, 0))), FALSE);
+  g_return_val_if_fail ((G_VALUE_HOLDS_STRING (g_array_index(param_values, GValue*, 1))), FALSE);
   g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 
   g_object_set_data (G_OBJECT (job), "jobtype", "imgur");
   if (exo_job_set_error_if_cancelled (EXO_JOB (job), error))
     return FALSE;
 
+  image_path = g_value_get_string (g_array_index (param_values, GValue*, 0));
+  title = g_value_get_string (g_array_index (param_values, GValue*, 1));
 
-  image_path = g_value_get_string (g_value_array_get_nth (param_values, 0));
-  title = g_value_get_string (g_value_array_get_nth (param_values, 1));
-
-  session = soup_session_sync_new ();
+  session = soup_session_new ();
 #if DEBUG > 0
   log = soup_logger_new (SOUP_LOGGER_LOG_HEADERS, -1);
   soup_session_add_feature (session, (SoupSessionFeature *)log);
@@ -105,14 +104,14 @@ imgur_upload_job (ScreenshooterJob *job, GValueArray *param_values, GError **err
   exo_job_info_message (EXO_JOB (job), _("Upload the screenshot..."));
   status = soup_session_send_message (session, msg);
 
-  if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code))
+  if (!SOUP_STATUS_IS_SUCCESSFUL (status))
     {
       TRACE ("Error during the POST exchange: %d %s\n",
-             msg->status_code, msg->reason_phrase);
+             status, msg->reason_phrase);
 
       tmp_error = g_error_new (SOUP_HTTP_ERROR,
-                         msg->status_code,
-                         _("An error occurred when transferring the data"
+                         status,
+                         _("An error occurred while transferring the data"
                            " to imgur."));
       g_propagate_error (error, tmp_error);
       g_object_unref (session);
@@ -129,7 +128,7 @@ imgur_upload_job (ScreenshooterJob *job, GValueArray *param_values, GError **err
   root_node = xmlDocGetRootElement(doc);
   for (child_node = root_node->children; child_node; child_node = child_node->next)
     if (xmlStrEqual(child_node->name, (const xmlChar *) "id"))
-       online_file_name = xmlNodeGetContent(child_node);
+       online_file_name = (gchar*)xmlNodeGetContent(child_node);
   TRACE("found picture id %s\n", online_file_name);
   xmlFreeDoc(doc);
   soup_buffer_free (buf);
@@ -163,7 +162,7 @@ void screenshooter_upload_to_imgur   (const gchar  *image_path,
 
   g_return_if_fail (image_path != NULL);
 
-  dialog = create_throbber_dialog(_("Imgur"), &label);
+  dialog = create_spinner_dialog(_("Imgur"), &label);
 
   job = screenshooter_simple_job_launch (imgur_upload_job, 2,
                                           G_TYPE_STRING, image_path,
